@@ -307,11 +307,11 @@ class MainWindow(QtGui.QMainWindow):
             clantag="None"
         if platform=="360":
             platform="Xbox 360" 
-        if lastcheck=="nochange":
-            lastcheck="Nothing has changed\nsince last check\n"
-            changeinfo=""
-        else:
-            pass    
+#        if lastcheck=="nochange":
+#            lastcheck="Nothing has changed\nsince last check\n"
+#            changeinfo=""
+#        else:
+#            pass    
             
 
         
@@ -320,7 +320,7 @@ class MainWindow(QtGui.QMainWindow):
         
         #Anzeige
 
-        self.ui.statsshow.setText("General:\n\n"+str(changeinfo)+str(lastcheck)+"\n"
+        self.ui.statsshow.setText("General:\n\n"
                                   "Playername: "+str(name)+"\n"
                                   "Platform: "+str(platform)+"\n"
                                   "Rank: "+str(rankname)+"\n"
